import { Subject } from 'rxjs';
import { DateGet } from '../../../../core/services/date/src';
import { DataConversor } from '../../../../core/services/data/src';
const Excel = require('xlsx/dist/xlsx.mini.min');
class Core {
    excelFileToJson(file, sheet = 0) {
        return new Promise(async (resolve) => {
            const fileArray = await file.arrayBuffer();
            const reader = new FileReader();
            reader.onload = (e) => {
                const data = new Uint8Array(fileArray);
                const workbook = Excel.read(data, {
                    type: 'array',
                    sheets: sheet
                });
                const workbookName = workbook.SheetNames[sheet];
                const json = Excel.utils.sheet_to_json(workbook.Sheets[workbookName]);
                resolve(json);
            };
            reader.readAsArrayBuffer(file);
        });
    }
    jsonToFile(userData, sheetName, fileName, properties) {
        return new Promise(resolve => {
            const currentDate = DateGet.currentDateString('YYYYMMDD_HHmmss');
            const _fileName = fileName == null ? `Export ${currentDate}` : `${fileName}`;
            const fileNameWidthDate = `${_fileName} ${currentDate}.xlsx`;
            const ws = Excel.utils.json_to_sheet(userData);
            const wb = Excel.utils.book_new();
            Excel.utils.book_append_sheet(wb, ws, 'Base');
            const file = Excel.write(wb, {
                Props: {
                    Title: properties.Title,
                    Author: properties.Author,
                    Company: properties.Company,
                    Category: properties.Category
                },
                bookType: 'xlsx',
                type: 'binary'
            });
            const type = 'application/octet-stream';
            const content = new Blob([DataConversor.binaryStringToArrayBuffer(file)], { type });
            const excelFile = new File([content], fileNameWidthDate, {
                lastModified: new Date().getMilliseconds(),
                type
            });
            resolve(excelFile);
        });
    }
}
export const ExcelConversor = new Core();
class Export {
    status$ = new Subject();
    static async saveFile(content, sheetName, _fileName = null) {
        const currentDate = DateGet.currentDateString('YYYYMMDD_HHmmss');
        const fileName = _fileName == null ? `Export ${currentDate}` : `${_fileName}`;
        const fileNameWidthDate = `${fileName} ${currentDate}.xlsx`;
        const ws = Excel.utils.json_to_sheet(content);
        const wb = Excel.utils.book_new();
        Excel.utils.book_append_sheet(wb, ws, sheetName);
        await Excel.writeFile(wb, fileNameWidthDate, { cellStyles: true });
        ExportExcel.clearSubject();
        return { code: 200, message: 'File saved successfully' };
    }
    static async saveFileFromMultiple(data, fileName = null) {
        const currentDate = DateGet.currentDateString('YYYYMMDD_HHmmss');
        const currentFileName = fileName == null ? `Export ${currentDate}` : `${fileName}`;
        const fileNameWidthDate = `${currentFileName} ${currentDate}.xlsx`;
        const wb = Excel.utils.book_new();
        for (const sheet of data) {
            const ws = Excel.utils.json_to_sheet(sheet.content);
            Excel.utils.book_append_sheet(wb, ws, sheet.sheetName);
        }
        await Excel.writeFile(wb, fileNameWidthDate, { cellStyles: true });
        ExportExcel.clearSubject();
        return { code: 200, message: 'File saved successfully' };
    }
    exportDatabase(userData, sheetName, fileName) {
        const single = { userData, fileName, sheetName };
        const multiple = {
            data: [],
            fileName: ''
        };
        return this.exportExcel('Single', single, multiple);
    }
    exportMultipleDatabase(data, fileName = null) {
        const single = {
            userData: [],
            fileName: '',
            sheetName: ''
        };
        const multiple = { data, fileName };
        return this.exportExcel('Multiple', single, multiple);
    }
    async exportExcel(type, singleData, multipleData) {
        this.status$.next('Creating Excel workbook...');
        return new Promise(async (resolve) => {
            let result;
            if (type === 'Single') {
                result = await Export.saveFile(singleData.userData, singleData.sheetName, singleData.fileName);
            }
            else {
                result = await Export.saveFileFromMultiple(multipleData.data, multipleData.fileName);
            }
            this.status$.next(result.message);
            if (result.code === 200) {
                resolve(result.message);
            }
            else {
                throw new Error(result.message);
            }
        });
    }
    clearSubject() {
        this.status$.observers.map(x => x.complete());
    }
}
export const ExportExcel = new Export();
//# sourceMappingURL=services-export-excel.service.js.map